searchNodes=[{"doc":"View helper functions for Phoenix and Flop.PaginationFlop.meta/3 returns a Flop.Meta struct, which holds information such as the total item count, the total page count, the current page etc. This is all you need to render pagination links. Flop.run/3, Flop.validate_and_run/3 and Flop.validate_and_run!/3 all return the query results alongside the meta information.If you set up your context as described in the Flop documentation, you will have a list function similar to the following:@spec list_pets(Flop.t() | map) :: {:ok, {[Pet.t()], Flop.Meta.t}} | {:error, Changeset.t()} def list_pets(flop \\\\ %{}) do Flop.validate_and_run(Pet, flop, for: Pet) endControllerYou can call this function from your controller to get both the data and the meta data and pass both to your template.defmodule MyAppWeb.PetController do use MyAppWeb, :controller alias Flop alias MyApp.Pets alias MyApp.Pets.Pet action_fallback MyAppWeb.FallbackController def index(conn, params) do with {:ok, {pets, meta}} &lt;- Pets.list_pets(params) do render(conn, &quot;index.html&quot;, meta: meta, pets: pets) end end endViewTo make the FlopPhoenix functions available in all templates, locate the view_helpers/0 macro in my_app_web.ex and add another import statement:defp view_helpers do quote do # ... import FlopPhoenix # ... end endTemplateIn your index template, you can now add pagination links like this:&lt;h1&gt;Listing Pets&lt;/h1&gt; &lt;table&gt; # ... &lt;/table&gt; &lt;%= pagination(@meta, &amp;Routes.pet_path/3, [@conn, :index]) %&gt;The second argument of FlopPhoenix.pagination/4 is the route helper function, and the third argument is a list of arguments for that route helper. If you want to add path parameters, you can do that like this:&lt;%= pagination(@meta, &amp;Routes.owner_pet_path/4, [@conn, :index, @owner]) %&gt;CustomizationFlopPhoenix sets some default classes and aria attributes.&lt;nav aria-label=&quot;pagination&quot; class=&quot;pagination is-centered&quot; role=&quot;navigation&quot;&gt; &lt;span class=&quot;pagination-previous&quot; disabled=&quot;disabled&quot;&gt;Previous&lt;/span&gt; &lt;a class=&quot;pagination-next&quot; href=&quot;/pets?page=2&amp;amp;page_size=10&quot;&gt;Next&lt;/a&gt; &lt;ul class=&quot;pagination-list&quot;&gt; &lt;li&gt;&lt;span class=&quot;pagination-ellipsis&quot;&gt;&amp;hellip;&lt;/span&gt;&lt;/li&gt; &lt;li&gt; &lt;a aria-current=&quot;page&quot; aria-label=&quot;Goto page 1&quot; class=&quot;pagination-link is-current&quot; href=&quot;/pets?page=1&amp;amp;page_size=10&quot;&gt;1&lt;/a&gt; &lt;/li&gt; &lt;li&gt; &lt;a aria-label=&quot;Goto page 2&quot; class=&quot;pagination-link&quot; href=&quot;/pets?page=2&amp;amp;page_size=10&quot;&gt;2&lt;/a&gt; &lt;/li&gt; &lt;li&gt; &lt;a aria-label=&quot;Goto page 3&quot; class=&quot;pagination-link&quot; href=&quot;/pets?page=3&amp;amp;page_size=2&quot;&gt;3&lt;/a&gt; &lt;/li&gt; &lt;li&gt;&lt;span class=&quot;pagination-ellipsis&quot;&gt;&amp;hellip;&lt;/span&gt;&lt;/li&gt; &lt;/ul&gt; &lt;/nav&gt;You can customize the css classes and add additional HTML attributes. It is recommended to set up the customization once in a view helper module, so that your templates aren't cluttered with options.Create a new file called views/flop_helpers.ex:defmodule MyAppWeb.FlopHelpers do use Phoenix.HTML def pagination(meta, route_helper, route_helper_args) do opts = [ # ... ] FlopPhoenix.pagination(meta, route_helper, route_helper_args, opts) end endChange the import in my_app_web.ex:defp view_helpers do quote do # ... import MyAppWeb.FlopHelpers # ... end endPage link optionsBy default, page links for all pages are show. You can limit the number of page links or disable them altogether by passing the :page_links option.:all: Show all page links (default).:hide: Don't show any page links. Only the previous/next links will be shown.{:ellipsis, x}: Show only x page links. Additional list items with ellipses are shown if there are more pages.Attributes and CSS classesYou can overwrite the default attributes of the &lt;nav&gt; tag and the pagination links by passing these options::wrapper_attrs: attributes for the &lt;nav&gt; tag:previous_link_attrs: attributes for the previous link (&lt;a&gt; if active, &lt;span&gt; if disabled):next_link_attrs: attributes for the next link (&lt;a&gt; if active, &lt;span&gt; if disabled):pagination_list_attrs: attributes for the page link list (&lt;ul&gt;):pagination_link_attrs: attributes for the page links (&lt;a&gt;):ellipsis_attrs: attributes for the ellipsis element (&lt;span&gt;):ellipsis_content: content for the ellipsis element (&lt;span&gt;)Pagination link aria labelFor the page links, there is the :pagination_link_aria_label option to set the aria label. Since the page number is usually part of the aria label, you need to pass a function that takes the page number as an integer and returns the label as a string. The default is &amp;&quot;Goto page \#{&amp;1}&quot;.Previous/next linksBy default, the previous and next links contain the texts Previous and Next. To change this, you can pass the :previous_link_content and :next_link_content options.Customization exampledef pagination(meta, route_helper, route_helper_args) do opts = [ ellipsis_attrs: [class: &quot;ellipsis&quot;], ellipsis_content: &quot;‥&quot;, next_link_attrs: [class: &quot;next&quot;], next_link_content: next_icon(), page_links: {:ellipsis, 7}, pagination_link_aria_label: &amp;&quot;\#{&amp;1}ページ目へ&quot;, pagination_link_attrs: [class: &quot;page-link&quot;], pagination_list_attrs: [class: &quot;page-links&quot;], previous_link_attrs: [class: &quot;prev&quot;], previous_link_content: previous_icon(), wrapper_attrs: [class: &quot;paginator&quot;] ] FlopPhoenix.pagination(meta, route_helper, route_helper_args, opts) end defp next_icon do content_tag :i, class: &quot;fas fa-chevron-right&quot; do end end defp previous_icon do content_tag :i, class: &quot;fas fa-chevron-left&quot; do end end","ref":"FlopPhoenix.html","title":"FlopPhoenix","type":"module"},{"doc":"Renders a pagination component.meta: The meta information of the query as returned by the Flop query functions.route_helper: The route helper function that builds a path to the current page, e.g. &amp;Routes.pet_path/3.route_helper_args: The arguments to be passed to the route helper function, e.g. [@conn, :index]. The page number and page size will be added as query parameters.opts: Options to customize the pagination. See section Customization.","ref":"FlopPhoenix.html#pagination/4","title":"FlopPhoenix.pagination/4","type":"function"},{"doc":"Flop PhoenixFlop Phoenix is an Elixir library for filtering, ordering and pagination with Ecto, Phoenix and Flop.","ref":"readme.html","title":"Flop Phoenix","type":"extras"},{"doc":"Add flop_phoenix to your list of dependencies in the mix.exs of your Phoenix application:def deps do [ {:flop_phoenix, &quot;~&gt; 0.3.0&quot;} ] endFollow the instructions in the Flop documentation to set up your business logic.","ref":"readme.html#installation","title":"Flop Phoenix - Installation","type":"extras"},{"doc":"In your controller, pass the data and the Flop meta struct to your template:defmodule MyAppWeb.PetController do use MyAppWeb, :controller alias Flop alias MyApp.Pets alias MyApp.Pets.Pet action_fallback MyAppWeb.FallbackController def index(conn, params) do with {:ok, {pets, meta}} &lt;- Pets.list_pets(params) do render(conn, &quot;index.html&quot;, meta: meta, pets: pets) end end endIn my_app_web.ex, find the view_helpers/0 macro and import FlopPhoenix:defp view_helpers do quote do # Use all HTML functionality (forms, tags, etc) use Phoenix.HTML # Import basic rendering functionality (render, render_layout, etc) import Phoenix.View + import FlopPhoenix import MyAppWeb.ErrorHelpers import MyAppWeb.Gettext alias MyAppWeb.Router.Helpers, as: Routes end endIn your index template, you can now add pagination links:&lt;h1&gt;Listing Pets&lt;/h1&gt; &lt;table&gt; # ... &lt;/table&gt; &lt;%= pagination(@meta, &amp;Routes.pet_path/3, [@conn, :index]) %&gt; &lt;span&gt;&lt;%= link &quot;New Pet&quot;, to: Routes.pet_path(@conn, :new) %&gt;&lt;/span&gt;The second argument of FlopPhoenix.pagination/4 is the route helper function, and the third argument is a list of arguments for that route helper. If you want to add path parameters, you can do that like this:&lt;%= pagination(@meta, &amp;Routes.owner_pet_path/4, [@conn, :index, @owner]) %&gt;","ref":"readme.html#usage","title":"Flop Phoenix - Usage","type":"extras"},{"doc":"If you want to customize the pagination markup, you would probably want to do that once for all templates. To do that, create a new file views/flop_helpers.ex.defmodule MyAppWeb.FlopHelpers do use Phoenix.HTML def pagination(meta, route_helper, route_helper_args) do opts = [ next_link_content: next_icon(), previous_link_content: previous_icon(), wrapper_attrs: [class: &quot;paginator&quot;] ] FlopPhoenix.pagination(meta, route_helper, route_helper_args, opts) end defp next_icon do content_tag :i, class: &quot;fas fa-chevron-right&quot; do end end defp previous_icon do content_tag :i, class: &quot;fas fa-chevron-left&quot; do end end endChange the import in my_app_web.ex:defp view_helpers do quote do # ... - import FlopPhoenix + import MyAppWeb.FlopHelpers # ... end endRefer to the FlopPhoenix docs for more information on the available options.","ref":"readme.html#customization","title":"Flop Phoenix - Customization","type":"extras"}]